@@ -76,6 +76,7 @@ var NAVTREE =
       [ "Subpaging", "grouping.html#subpaging", null ]
     ] ],
     [ "Including formulas", "formulas.html", null ],
+    [ "Including tables", "tables.html", null ],
     [ "Graphs and diagrams", "diagrams.html", null ],
     [ "Preprocessing", "preprocessing.html", null ],
     [ "Automatic link generation", "autolink.html", [
@@ -354,6 +355,7 @@ var NAVTREE =
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.8 Series", "changelog.html#log_1_8", [
+        [ "Release 1.8.11", "changelog.html#log_1_8_11", null ],
         [ "Release 1.8.10", "changelog.html#log_1_8_10", null ],
         [ "Release 1.8.9.1", "changelog.html#log_1_8_9_1", null ],
         [ "Release 1.8.9", "changelog.html#log_1_8_9", null ],
@@ -379,7 +381,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"docblocks.html#tclblocks"
+"docblocks.html#structuralcommands"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
